@@ -95,59 +95,16 @@ class Measure(Generic[T], JSONEncoder):
     def print(self, *metrics: Union[MetricName, str], output: Union[TextIO, str] = stdout) -> None:
         """ Print a measure with different metrics.
         :param metrics: The list to measures to print.
-        :param output: The file handler or the file path where the result are printed.
-           By default in the standard output.
+        :param output: The file handler or the file path where the result are stored.
+           By default, it is printed in the standard output.
         """
         metrics = metrics if metrics else {(str(metric)) for metric in self.metrics}
         file = open_file(output, 'wt') if isinstance(output, str) else output
-        # if str(MetricName.SIMPLE_ACCURACY).lower() in metrics or MetricName.BALANCED_ACCURACY in metrics:
-        #     self._print_metric_if_show('Simple accuracy', MetricName.SIMPLE_ACCURACY, *metrics, file=file)
-        #     self._print_metric_if_show('Balanced accuracy', MetricName.BALANCED_ACCURACY, *metrics, file=file)
-        #     print(file=file)
-        # if MetricName.MICRO_F1 in metrics or MetricName.MACRO_F1 in metrics or MetricName.WEIGHTED_F1 in metrics:
-        #     self._print_metric_if_show('Micro f-measure', MetricName.MICRO_F1, *metrics, file=file)
-        #     self._print_metric_if_show('Macro f-measure', MetricName.MACRO_F1, *metrics, file=file)
-        #     self._print_metric_if_show('Weighted f-measure', MetricName.WEIGHTED_F1, *metrics, file=file)
-        #     print(file=file)
-        # if MetricName.MICRO_PRECISION in metrics or\
-        #         MetricName.MACRO_PRECISION in metrics or\
-        #         MetricName.WEIGHTED_PRECISION in metrics:
-        #     self._print_metric_if_show('Micro precision', MetricName.MICRO_PRECISION, *metrics, file=file)
-        #     self._print_metric_if_show('Macro precision', MetricName.MACRO_PRECISION, *metrics, file=file)
-        #     self._print_metric_if_show('Weighted precision', MetricName.WEIGHTED_PRECISION, *metrics, file=file)
-        #     print(file=file)
-        # if MetricName.MICRO_RECALL in metrics or\
-        #         MetricName.MACRO_RECALL in metrics or\
-        #         MetricName.WEIGHTED_RECALL in metrics:
-        #     self._print_metric_if_show('Micro recall', MetricName.MICRO_RECALL, *metrics, file=file)
-        #     self._print_metric_if_show('Macro recall', MetricName.MACRO_RECALL, *metrics, file=file)
-        #     self._print_metric_if_show('Weighted recall', MetricName.WEIGHTED_RECALL, *metrics, file=file)
-        #     print(file=file)
-        # if MetricName.MICRO_JACCARD in metrics or\
-        #         MetricName.MACRO_JACCARD in metrics or\
-        #         MetricName.WEIGHTED_JACCARD in metrics:
-        #     self._print_metric_if_show('Micro Jaccard', MetricName.MICRO_JACCARD, *metrics, file=file)
-        #     self._print_metric_if_show('Macro Jaccard', MetricName.MACRO_JACCARD, *metrics, file=file)
-        #     self._print_metric_if_show('Weighted Jaccard', MetricName.WEIGHTED_JACCARD, *metrics, file=file)
-        #     print(file=file)
         for i, metric in enumerate(metrics):
-            if i % 3 == 0:
-                print(file=file)
-            print(f'{metric}: ', self[metric].format(), end='\t', file=file)
+            print(f'{metric}: ', self[metric].format(), end='\n' if i % 3 == 0 else '\t', file=file)
         if isinstance(output, str):
             file.close()
 
-    # def _print_metric_if_show(self, msg: str, metric: MetricName, *show: MetricName, file: TextIO):
-    #     """ Print a given metric if that metric is selected.
-    #     :param msg: The message to print with the metric.
-    #     :param metrics: All obtained metrics.
-    #     :param metric: The metric to print.
-    #     :param show: The list of metrics which will be printed.
-    #     :param file: The file handler where the result are printed. By default in the standard output.
-    #     """
-    #     if metric in show:
-    #         print(f'{msg}: ', self[metric].format(), end='\t', file=file)
-
     def min_uncertainty(self) -> Metric:
         min_ci = None
         for metric in self.__metrics.values():
